@@ -12,7 +12,7 @@ import java.io.File
 
 import androidx.appcompat.app.AppCompatActivity
 import androidx.recyclerview.widget.RecyclerView
-import androidx.lifecycle.ViewModelProviders
+import androidx.lifecycle.ViewModelProvider
 import androidx.lifecycle.Observer
 import androidx.core.app.ActivityCompat
 import androidx.appcompat.app.AppCompatDelegate
@@ -33,10 +33,9 @@ import android.content.Context
 import android.widget.Toast
 import android.content.SharedPreferences
 import android.content.pm.PackageManager
-import android.graphics.drawable.ColorDrawable
+import android.content.res.Resources
 import android.view.*
-
-import com.google.android.material.snackbar.Snackbar
+import androidx.preference.PreferenceManager.getDefaultSharedPreferences
 
 import io.reactivex.disposables.CompositeDisposable
 import io.reactivex.schedulers.Schedulers
@@ -50,6 +49,9 @@ import kotlinx.android.synthetic.main.hello_layout.*
 import com.github.angads25.filepicker.model.DialogConfigs
 import com.github.angads25.filepicker.model.DialogProperties
 import com.github.angads25.filepicker.view.FilePickerDialog
+import com.yariksoffice.lingver.Lingver
+import java.io.BufferedReader
+import java.util.*
 
 /**
  * An activity representing a list of Pings. This activity
@@ -124,7 +126,7 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
                         }
                     }
                     "file" -> {
-                        val file = File(uri.path)
+                        val file = File(uri.path.orEmpty())
                         try {
                             fd = ParcelFileDescriptor.open(file, ParcelFileDescriptor.MODE_READ_ONLY)
                         } catch (e: Exception) {}
@@ -195,39 +197,72 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
         handleIntent(intent)
     }
 
+    private fun handleUri(uri: Uri) {
+        if (uri.scheme == "file") {
+            if (Build.VERSION.SDK_INT >= 23) {
+                if (checkSelfPermission(android.Manifest.permission.READ_EXTERNAL_STORAGE) != PackageManager.PERMISSION_GRANTED) {
+                    pendingFileUris.add(uri)
+                    ActivityCompat.requestPermissions(this@ReportListActivity,
+                            arrayOf(android.Manifest.permission.READ_EXTERNAL_STORAGE),
+                            READ_EXTERNAL_STORAGE_PERMISSION_REQUEST)
+                    return
+                }
+            }
+        }
+        AddFile().execute(uri)
+    }
+
     private fun handleIntent(intent: Intent) {
         if (intent.action != null) {
             val action: String? = intent.action
-            val uri: Uri? = intent.data
-            if (action == Intent.ACTION_VIEW && uri != null) {
-                if (uri.scheme == "file") {
-                    if (Build.VERSION.SDK_INT >= 23) {
-                        if (checkSelfPermission(android.Manifest.permission.READ_EXTERNAL_STORAGE) != PackageManager.PERMISSION_GRANTED) {
-                            pendingFileUris.add(uri)
-                            ActivityCompat.requestPermissions(this@ReportListActivity,
-                                    arrayOf(android.Manifest.permission.READ_EXTERNAL_STORAGE),
-                                    READ_EXTERNAL_STORAGE_PERMISSION_REQUEST)
-                            return
+            if (action == Intent.ACTION_VIEW) {
+                val uri: Uri? = intent.data
+                if (uri != null) {
+                    handleUri(uri)
+                }
+            } else if (action == Intent.ACTION_SEND) {
+                val uri = intent.getParcelableExtra<Uri>(Intent.EXTRA_STREAM)
+                if (uri != null) {
+                    handleUri(uri)
+                } else if (action == Intent.ACTION_SEND_MULTIPLE) {
+                    val uriList = intent.getParcelableArrayListExtra<Uri>(Intent.EXTRA_STREAM)
+                    if (uriList != null) {
+                        for (i in uriList) {
+                            handleUri(i)
                         }
                     }
                 }
-
-                AddFile().execute(uri)
             }
         }
     }
 
     private fun applyUiMode() {
-        val sharedPreferences: SharedPreferences? = getSharedPreferences(getString(R.string.preferences_key), Context.MODE_PRIVATE)
-        sharedPreferences?.getString(getString(R.string.preferences_uimode_key), "OFF").let {
+        val sharedPreferences = getDefaultSharedPreferences(this)
+        val key = getString(R.string.preferences_uimode_key)
+        if (sharedPreferences?.contains(key) == false) {
+            val oldSharedPreferences = getSharedPreferences(getString(R.string.preferences_key), Context.MODE_PRIVATE)
+            oldSharedPreferences.getString(key, "").let {
+                when (it) {
+                    "ON" -> {
+                        sharedPreferences.edit()?.putBoolean(key, true)?.apply()
+                    }
+                    "OFF" -> {
+                        sharedPreferences.edit()?.putBoolean(key, false)?.apply()
+                    }
+                    else -> {}
+                }
+            }
+        }
+
+        sharedPreferences?.getBoolean(getString(R.string.preferences_uimode_key), false).let {
             when (it) {
-                "OFF" -> {
+                false -> {
                     if (AppCompatDelegate.getDefaultNightMode()!=AppCompatDelegate.MODE_NIGHT_NO) {
                         AppCompatDelegate.setDefaultNightMode(AppCompatDelegate.MODE_NIGHT_NO)
                         recreate()
                     }
                 }
-                "ON" -> {
+                true -> {
                     if (AppCompatDelegate.getDefaultNightMode()!=AppCompatDelegate.MODE_NIGHT_YES) {
                         AppCompatDelegate.setDefaultNightMode(AppCompatDelegate.MODE_NIGHT_YES)
                         recreate()
@@ -243,6 +278,55 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
         }
     }
 
+    private fun setLocale() {
+        try {
+            val stream = applicationContext.resources.openRawResource(R.raw.lang)
+            val content = stream.bufferedReader().use(BufferedReader::readText)
+            Core.setLocale(content)
+        }
+        catch (error: Exception) {
+        }
+    }
+
+    private fun setPrefLocale() {
+        val sharedPreferences: SharedPreferences? = getDefaultSharedPreferences(this)
+        sharedPreferences?.getBoolean(getString(R.string.preferences_report_translate_key), false).let {
+            when (it) {
+                false -> {
+                    Core.setLocale("")
+                }
+                true -> {
+                    setLocale()
+                }
+            }
+        }
+
+        sharedPreferences?.getString(getString(R.string.preferences_locale_key), "system").let {
+            val locale: Locale =
+                if (it == null || it == "system") {
+                    if (Build.VERSION.SDK_INT >= 24) {
+                        Resources.getSystem().configuration.locales.get(0)
+                    } else {
+                        Resources.getSystem().configuration.locale
+                    }
+                } else {
+                    val language = it.split("-r")
+                    if (language.size > 1) {
+                        Locale(language[0], language[1])
+                    } else {
+                        Locale(language[0])
+                    }
+                }
+
+            Locale.setDefault(locale)
+
+            if (Lingver.getInstance().getLocale() != locale) {
+                Lingver.getInstance().setLocale(this, locale)
+                recreate()
+            }
+        }
+    }
+
     fun deleteReport(id: Int) {
         disposable.add(reportModel
                 .deleteReport(id)
@@ -274,92 +358,9 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
             }
         })
 
-        val sharedPreferences: SharedPreferences? = getSharedPreferences(getString(R.string.preferences_key), Context.MODE_PRIVATE)
-        sharedPreferences?.getString(getString(R.string.preferences_uimode_key), "OFF").let {
-            if (it != null) {
-                when (it) {
-                    "OFF" -> {
-                        menu?.findItem(R.id.action_nightmode).let { item ->
-                            item?.setChecked(false)
-                        }
-                        /* menu?.findItem(R.id.action_nightmode_auto).let { item ->
-                            item?.setChecked(false)
-                        } */
-                    }
-                    "ON" -> {
-                        menu?.findItem(R.id.action_nightmode).let { item ->
-                            item?.setChecked(true)
-                        }
-                        /* menu?.findItem(R.id.action_nightmode_auto).let { item ->
-                            item?.setChecked(false)
-                        } */
-                    }
-                    /* "AUTO" -> {
-                        menu?.findItem(R.id.action_nightmode_auto).let { item ->
-                            item?.setChecked(true)
-                        }
-                        menu?.findItem(R.id.action_nightmode).let { item ->
-                            item?.setEnabled(false)
-                        }
-                    } */
-                }
-            }
-        }
-
-        menu?.findItem(R.id.action_nightmode).let {
-            it?.setOnMenuItemClickListener { item ->
-                if (item.isChecked()) {
-                    item.setChecked(false)
-                    sharedPreferences
-                            ?.edit()
-                            ?.putString(getString(R.string.preferences_uimode_key), "OFF")
-                            ?.apply()
-
-                    applyUiMode()
-                } else {
-                    item.setChecked(true)
-                    sharedPreferences
-                            ?.edit()
-                            ?.putString(getString(R.string.preferences_uimode_key), "ON")
-                            ?.apply()
-
-                    applyUiMode()
-                }
-
-                true
-            }
-        }
-
-        /* menu?.findItem(R.id.action_nightmode_auto).let {
-            it?.setOnMenuItemClickListener {
-                if (it.isChecked()) {
-                    it.setChecked(false)
-                    sharedPreferences
-                            ?.edit()
-                            ?.putString(getString(R.string.preferences_uimode_key), "OFF")
-                            ?.apply()
-                    menu?.findItem(R.id.action_nightmode).let { item ->
-                        item?.setEnabled(true)
-                    }
-                    applyUiMode()
-                } else {
-                    it.setChecked(true)
-                    sharedPreferences
-                            ?.edit()
-                            ?.putString(getString(R.string.preferences_uimode_key), "AUTO")
-                            ?.apply()
-                    menu?.findItem(R.id.action_nightmode).let { item ->
-                        item?.setEnabled(false)
-                    }
-                    applyUiMode()
-                }
-                true
-            }
-        } */
-
         subscriptionManager.subscribed.observe(this, Observer {
             if (it) {
-                menu?.findItem(R.id.action_nightmode)?.isVisible=true
+                //menu?.findItem(R.id.action_settings)?.isVisible=true
                 menu?.findItem(R.id.action_subscribe).let { item ->
                     item?.isEnabled=true
                     item?.title = getString(R.string.subscribed_text)
@@ -372,20 +373,13 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
                         true
                     }
                 }
-
-                if (!Core.thanked) {
-                    // Show thanks message
-                    Core.thanked=true
-                    val toast = Toast.makeText(applicationContext, R.string.thanks_text, Toast.LENGTH_SHORT)
-                    toast.show()
-                }
             } else {
                 menu?.findItem(R.id.action_subscribe).let { item ->
                     item?.title = getString(R.string.subscribe_text)
 
                     item?.setOnMenuItemClickListener { _ ->
                         val intent = Intent(this, SubscribeActivity::class.java)
-                        startActivity(intent)
+                        startActivityForResult(intent, SUBSCRIBE_REQUEST)
 
                         true
                     }
@@ -402,10 +396,21 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
             }
         }
 
+        menu?.findItem(R.id.action_settings).let {
+            it?.setOnMenuItemClickListener {
+                val intent = Intent(this, SettingsActivity::class.java)
+                startActivity(intent)
+
+                true
+            }
+        }
+
         return super.onCreateOptionsMenu(menu)
     }
 
     override fun onActivityResult(requestCode: Int, resultCode: Int, resultData: Intent?) {
+        super.onActivityResult(requestCode, resultCode, resultData)
+
         if (resultCode == Activity.RESULT_OK) {
             when (requestCode) {
                 OPEN_FILE_REQUEST -> {
@@ -424,6 +429,9 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
                         }
                     }
                 }
+                SUBSCRIBE_REQUEST -> {
+                    Toast.makeText(applicationContext, R.string.thanks_text, Toast.LENGTH_SHORT).show()
+                }
             }
         }
     }
@@ -442,14 +450,16 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
         subscriptionManager = SubscriptionManager.getInstance(application)
         lifecycle.addObserver(subscriptionManager)
 
+        setLocale()
         subscriptionManager.subscribed.observe(this, Observer {
-            if (it==true)
+            if (it==true) {
                 applyUiMode()
+                setPrefLocale()
+            }
         })
 
         val viewModelFactory = Injection.provideViewModelFactory(this)
-        ViewModelProviders.of(this, viewModelFactory).get(ReportViewModel::class.java)
-        reportModel = ViewModelProviders.of(this, viewModelFactory).get(ReportViewModel::class.java)
+        reportModel = ViewModelProvider(this, viewModelFactory).get(ReportViewModel::class.java)
 
         add_button.setOnClickListener {
             if (Build.VERSION.SDK_INT >= 19) {
@@ -490,6 +500,25 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
             }
         }
 
+        clear_btn.setOnClickListener {
+            disposable.add(reportModel.deleteAllReports()
+                .subscribeOn(Schedulers.io())
+                .observeOn(AndroidSchedulers.mainThread())
+                .subscribe {
+                    if (twoPane) {
+                        val fragment = supportFragmentManager.findFragmentById(R.id.report_detail_container)
+                        if (fragment != null) {
+                            supportFragmentManager
+                                .beginTransaction()
+                                .detach(fragment)
+                                .commit()
+
+                                title = getString(R.string.app_name)
+                        }
+                    }
+            })
+        }
+
         // The detail container view will be present only in the
         // large-screen layouts (res/values-w900dp).
         // If this view is present, then the
@@ -504,6 +533,7 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
 
     override fun onStart() {
         super.onStart()
+
         disposable.add(reportModel.getAllReports()
                 .subscribeOn(Schedulers.io())
                 .observeOn(AndroidSchedulers.mainThread())
@@ -521,12 +551,17 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
 
                         if (!found)
                             View.inflate(this, R.layout.hello_layout, rootLayout)
+
+                        clear_btn.visibility = View.INVISIBLE
                     } else {
                         for (i: Int in rootLayout.childCount downTo 1) {
                             if (rootLayout.getChildAt(i - 1).id == R.id.hello_layout)
                                 rootLayout.removeViewAt(i - 1)
                         }
                         rootLayout.removeView(hello_layout)
+                        clear_btn.visibility = View.VISIBLE
+
+
                     }
                 })
     }
@@ -540,6 +575,7 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
 
     private fun setupRecyclerView(recyclerView: RecyclerView) {
         recyclerView.adapter = ItemRecyclerViewAdapter(this, reports, twoPane)
+        recyclerView.isNestedScrollingEnabled = false
     }
 
     class ItemRecyclerViewAdapter(private val parentActivity: ReportListActivity,
@@ -604,6 +640,7 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
     }
 
     companion object {
+        const val SUBSCRIBE_REQUEST = 30
         const val OPEN_FILE_REQUEST= 40
         const val READ_EXTERNAL_STORAGE_PERMISSION_REQUEST = 50
     }
